+++
title = "Multiple example blocks inside quote block"
tags = ["quotes"]
draft = false
+++

Some text.

> Some quoted text.
>
> ```text
> (some-example)
> ```
>
> ````text
> (some-other-example)
> ````

Some other text.
